
# geemap

[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/geemap-colab)
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/giswqs/geemap/master)
[![image](https://binder.pangeo.io/badge_logo.svg)](https://binder.pangeo.io/v2/gh/giswqs/geemap/master)
[![image](https://img.shields.io/pypi/v/geemap.svg)](https://pypi.python.org/pypi/geemap)
[![image](https://img.shields.io/conda/vn/conda-forge/geemap.svg)](https://anaconda.org/conda-forge/geemap)
[![image](https://pepy.tech/badge/geemap)](https://pepy.tech/project/geemap)
[![image](https://readthedocs.org/projects/geemap/badge/?version=latest)](https://geemap.readthedocs.io/en/latest/?badge=latest)
[![image](https://img.shields.io/badge/YouTube-GEE%20Tutorials-red)](https://gishub.org/geemap)
[![image](https://img.shields.io/twitter/follow/giswqs?style=social%20%20%20%20..%20image::%20https://readthedocs.org/projects/geemap/badge/?version=latest)](https://twitter.com/giswqs)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## YouTube Channel

More video tutorials for geemap and Earth Engine are available on my [YouTube channel](https://www.youtube.com/c/QiushengWu). If you can't access YouTube in your country, you can try [西瓜视频](http://gishub.org/xigua) or [哔哩哔哩](https://space.bilibili.com/527404442)。

[![Earth Engine Tutorials on YouTube](https://wetlands.io/file/images/youtube.png)](https://www.youtube.com/c/QiushengWu)

## Tutorials

1. [Introducing the geemap Python package for interactive mapping with Google Earth Engine](#1-introducing-the-geemap-python-package-for-interactive-mapping-with-google-earth-engine) ([video](https://youtu.be/h0pz3S6Tvx0) | [gif](https://i.imgur.com/pI39k7v.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/01_geemap_intro.ipynb))
2. [Using basemaps in geemap and ipyleaflet for interactive mapping with Google Earth Engine](#2-using-basemaps-in-geemap-and-ipyleaflet-for-interactive-mapping-with-google-earth-engine) ([video](https://youtu.be/6J5ZCIUPXfI) | [gif](https://i.imgur.com/P5B2f7p.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/02_using_basemaps.ipynb)) 
3. [Introducing the Inspector tool for Earth Engine Python API](#3-introducing-the-inspector-tool-for-earth-engine-python-api) ([video](https://youtu.be/k477ksjkaXw) | [gif](https://i.imgur.com/8d77gtI.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/03_inspector_tool.ipynb))
4. [Creating a split-panel map for visualizing Earth Engine data](#4-creating-a-split-panel-map-for-visualizing-earth-engine-data) ([video](https://youtu.be/9EUTX8j-YVM) | [gif](https://i.imgur.com/kql7pC3.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/04_split_panel_map.ipynb))
5. [Using drawing tools to interact with Earth Engine data](#5-using-drawing-tools-to-interact-with-earth-engine-data) ([video](https://youtu.be/N7rK2aV1R4c) | [gif](https://i.imgur.com/Lm5pDUr.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/05_drawing_tools.ipynb))
6. [Creating an interactive map with a marker cluster](#6-creating-an-interactive-map-with-a-marker-cluster) ([video](https://youtu.be/4HycJPrwpuo) | [gif](https://i.imgur.com/GF4cOqh.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/06_marker_cluster.ipynb))
7. [Converting data formats between GeoJSON and Earth Engine](#7-converting-data-formats-between-geojson-and-earth-engine) ([video](https://youtu.be/DbK_SRgrCHw) | [gif](https://i.imgur.com/hVPmUG1.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/07_geojson.ipynb))
8. [Automated conversion from Earth Engine JavaScripts to Python scripts and Jupyter notebooks](#8-automated-conversion-from-earth-engine-javascripts-to-python-scripts-and-jupyter-notebooks) ([video](https://youtu.be/RpIaalFk4H8) | [gif](https://i.imgur.com/BW0zJnN.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/08_ee_js_to_ipynb.ipynb))
9. [Interactive plotting of Earth Engine data with minimal coding](#9-interactive-plotting-of-earth-engine-data-with-minimal-coding) ([video](https://youtu.be/PDab8mkAFL0) | [gif](https://i.imgur.com/iGMRnRb.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/09_plotting.ipynb))
10. [Using shapefiles with Earth Engine without having to upload data to GEE](#10-using-shapefiles-with-earth-engine-without-having-to-upload-data-to-gee) ([video](https://youtu.be/OlNlqfj4uHo) | [gif](https://i.imgur.com/W3vNSdX.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/10_shapefiles.ipynb))
11. [Exporting Earth Engine Image and ImageCollection as GeoTIFF and Numpy array](#11-exporting-earth-engine-image-and-imagecollection-as-geotiff-and-numpy-array) ([video](https://youtu.be/_6JOA-iiEGU) | [gif](https://i.imgur.com/RonLr0j.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/11_export_image.ipynb))
12. [Computing zonal statistics with Earth Engine and exporting results as CSV or shapefile](#12-computing-zonal-statistics-with-earth-engine-and-exporting-results-as-csv-or-shapefile) ([video](https://youtu.be/ou-Xm3CLitM) | [gif](https://i.imgur.com/8xmUitW.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/12_zonal_statistics.ipynb))
13. [Calculating zonal statistics by group (e.g., analyzing land cover composition of each country/state)](#13-calculating-zonal-statistics-by-group-eg-analyzing-land-cover-composition-of-each-countrystate) ([video](https://youtu.be/cORcGGH03gg) | [gif](https://i.imgur.com/LxD2em9.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/13_zonal_statistics_by_group.ipynb))
14. [Adding a customized legend for Earth Engine data](#14-adding-a-customized-legend-for-earth-engine-data) ([video](https://youtu.be/NwnW_qOkNRw) | [gif](https://i.imgur.com/idkZHQp.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/14_legends.ipynb))
15. [Converting Earth Engine JavaScripts to Python code directly within Jupyter notebook](#15-converting-earth-engine-javascripts-to-python-code-directly-within-jupyter-notebook) ([video](https://youtu.be/nAzZjKKd4w0) | [gif](https://i.imgur.com/aGCBWSV.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/15_convert_js_to_py.ipynb))
16. [Adding animated text to GIF images generated from Earth Engine data](#16-adding-animated-text-to-gif-images-generated-from-earth-engine-data) ([video](https://youtu.be/fDnDVuM_Ke4) | [gif](https://i.imgur.com/MSde1om.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/16_add_animated_text.ipynb))
17. [Adding colorbar and images to GIF animations generated from Earth Engine data](#17-adding-colorbar-and-images-to-gif-animations-generated-from-earth-engine-data) ([video](https://youtu.be/CpT3LQPNKJs) | [gif](https://i.imgur.com/13tFMSI.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/17_add_colorbar_to_gif.ipynb))
18. [Creating Landsat timelapse animations with animated text using Earth Engine](#18-creating-landsat-timelapse-animations-with-animated-text-using-earth-engine) ([video](https://youtu.be/OwjSJnGWKJs) | [gif](https://i.imgur.com/XOHOeXk.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/18_create_landsat_timelapse.ipynb))
19. [How to search and import datasets from Earth Engine Data Catalog](#19-how-to-search-and-import-datasets-from-earth-engine-data-catalog) ([video](https://youtu.be/lwtgzrHrXj8) | [gif](https://i.imgur.com/E09p64F.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/19_search_places_and_datasets.ipynb))
20. [Using timeseries inspector to visualize landscape changes over time](#20-using-timeseries-inspector-to-visualize-landscape-changes-over-time) ([video](https://youtu.be/0CZ7Aj8hCyo) | [gif](https://i.imgur.com/61wbRjK.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/20_timeseries_inspector.ipynb))
21. [Exporting Earth Engine maps as HTML files and PNG images](#21-exporting-earth-engine-maps-as-html-files-and-png-images) ([video](https://youtu.be/GWMvaNQz3kY) | [gif](https://i.imgur.com/rJuXH4a.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/21_export_map_to_html_png.ipynb))
22. [How to import Earth Engine Python scripts into Jupyter notebook?](#22-how-to-import-earth-engine-python-scripts-into-jupyter-notebook) ([video](https://youtu.be/V7CbB9W41w8) | [gif](https://i.imgur.com/WwJoBHF.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/22_import_scripts.ipynb))
23. [How to search Earth Engine API and import assets from GEE personal account?](#23-how-to-search-earth-engine-api-and-import-assets-from-gee-personal-account) ([video](https://youtu.be/c9VJ_uRYSkw) | [gif](https://i.imgur.com/b1auzkr.gif) | [notebook](https://github.com/giswqs/geemap/blob/master/examples/notebooks/22_import_assets.ipynb))

### 1. Introducing the geemap Python package for interactive mapping with Google Earth Engine

![Intro geemap](https://i.imgur.com/pI39k7v.gif)

### 2. Using basemaps in geemap and ipyleaflet for interactive mapping with Google Earth Engine

![basemaps](https://i.imgur.com/P5B2f7p.gif)

### 3. Introducing the Inspector tool for Earth Engine Python API

![Inspector tool](https://i.imgur.com/8d77gtI.gif)

### 4. Creating a split-panel map for visualizing Earth Engine data

![Split panel](https://i.imgur.com/kql7pC3.gif)

### 5. Using drawing tools to interact with Earth Engine data

![Drawing tools](https://i.imgur.com/Lm5pDUr.gif)

### 6. Creating an interactive map with a marker cluster

![Marker cluster](https://i.imgur.com/GF4cOqh.gif)

### 7. Converting data formats between GeoJSON and Earth Engine

![GeoJSON](https://i.imgur.com/hVPmUG1.gif)

### 8. Automated conversion from Earth Engine JavaScripts to Python scripts and Jupyter notebooks

![Conversion](https://i.imgur.com/BW0zJnN.gif)

### 9. Interactive plotting of Earth Engine data with minimal coding

![Plotting](https://i.imgur.com/iGMRnRb.gif)

### 10. Using shapefiles with Earth Engine without having to upload data to GEE

![shapefile](https://i.imgur.com/W3vNSdX.gif)

### 11. Exporting Earth Engine Image and ImageCollection as GeoTIFF and Numpy array

![exporting](https://i.imgur.com/RonLr0j.gif)

### 12. Computing zonal statistics with Earth Engine and exporting results as CSV or shapefile

![zonal](https://i.imgur.com/8xmUitW.gif)

### 13. Calculating zonal statistics by group (e.g., analyzing land cover composition of each country/state)

![zonal by group](https://i.imgur.com/LxD2em9.gif)

### 14. Adding a customized legend for Earth Engine data

![legend](https://i.imgur.com/idkZHQp.gif)

### 15. Converting Earth Engine JavaScripts to Python code directly within Jupyter notebook

![js-py](https://i.imgur.com/aGCBWSV.gif)

### 16. Adding animated text to GIF images generated from Earth Engine data

![animated text](https://i.imgur.com/MSde1om.gif)

### 17. Adding colorbar and images to GIF animations generated from Earth Engine data

![logo](https://i.imgur.com/13tFMSI.gif)

### 18. Creating Landsat timelapse animations with animated text using Earth Engine

![timelapse](https://i.imgur.com/XOHOeXk.gif)

### 19. How to search and import datasets from Earth Engine Data Catalog

![search](https://i.imgur.com/E09p64F.gif)

### 20. Using timeseries inspector to visualize landscape changes over time

![ts inspector](https://i.imgur.com/61wbRjK.gif)

### 21. Exporting Earth Engine maps as HTML files and PNG images

![export html](https://i.imgur.com/rJuXH4a.gif)

### 22. How to import Earth Engine Python scripts into Jupyter notebook?

![import scripts](https://i.imgur.com/WwJoBHF.gif)

### 23. How to search Earth Engine API and import assets from GEE personal account?

![import assets](https://i.imgur.com/b1auzkr.gif)